/****************************************************************************
** Meta object code from reading C++ file 'udptrackersocket.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libktorrent-26.07.80/src/tracker/udptrackersocket.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udptrackersocket.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2bt16UDPTrackerSocketE_t {};
} // unnamed namespace

template <> constexpr inline auto bt::UDPTrackerSocket::qt_create_metaobjectdata<qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "bt::UDPTrackerSocket",
        "connectReceived",
        "",
        "Int32",
        "tid",
        "Int64",
        "connection_id",
        "announceReceived",
        "const Uint8*",
        "buf",
        "Uint32",
        "size",
        "scrapeReceived",
        "error",
        "error_string"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectReceived'
        QtMocHelpers::SignalData<void(Int32, Int64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'announceReceived'
        QtMocHelpers::SignalData<void(Int32, const Uint8 *, Uint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'scrapeReceived'
        QtMocHelpers::SignalData<void(Int32, const Uint8 *, Uint32)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(Int32, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UDPTrackerSocket, qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject bt::UDPTrackerSocket::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>.metaTypes,
    nullptr
} };

void bt::UDPTrackerSocket::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UDPTrackerSocket *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectReceived((*reinterpret_cast<std::add_pointer_t<Int32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Int64>>(_a[2]))); break;
        case 1: _t->announceReceived((*reinterpret_cast<std::add_pointer_t<Int32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Uint8*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Uint32>>(_a[3]))); break;
        case 2: _t->scrapeReceived((*reinterpret_cast<std::add_pointer_t<Int32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Uint8*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Uint32>>(_a[3]))); break;
        case 3: _t->error((*reinterpret_cast<std::add_pointer_t<Int32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UDPTrackerSocket::*)(Int32 , Int64 )>(_a, &UDPTrackerSocket::connectReceived, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UDPTrackerSocket::*)(Int32 , const Uint8 * , Uint32 )>(_a, &UDPTrackerSocket::announceReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UDPTrackerSocket::*)(Int32 , const Uint8 * , Uint32 )>(_a, &UDPTrackerSocket::scrapeReceived, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UDPTrackerSocket::*)(Int32 , const QString & )>(_a, &UDPTrackerSocket::error, 3))
            return;
    }
}

const QMetaObject *bt::UDPTrackerSocket::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::UDPTrackerSocket::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16UDPTrackerSocketE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::UDPTrackerSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void bt::UDPTrackerSocket::connectReceived(Int32 _t1, Int64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void bt::UDPTrackerSocket::announceReceived(Int32 _t1, const Uint8 * _t2, Uint32 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void bt::UDPTrackerSocket::scrapeReceived(Int32 _t1, const Uint8 * _t2, Uint32 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void bt::UDPTrackerSocket::error(Int32 _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
