/****************************************************************************
** Meta object code from reading C++ file 'torrentinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libktorrent-26.07.80/src/interfaces/torrentinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'torrentinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2bt16TorrentInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto bt::TorrentInterface::qt_create_metaobjectdata<qt_meta_tag_ZN2bt16TorrentInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "bt::TorrentInterface",
        "finished",
        "",
        "bt::TorrentInterface*",
        "me",
        "stoppedByError",
        "msg",
        "maxRatioChanged",
        "seedingAutoStopped",
        "bt::AutoStopReason",
        "reason",
        "aboutToBeStarted",
        "bool&",
        "ret",
        "missingFilesMarkedDND",
        "corruptedDataFound",
        "diskSpaceLow",
        "toStop",
        "torrentStopped",
        "needDataCheck",
        "statusChanged",
        "chunkDownloaded",
        "bt::Uint32",
        "chunk",
        "updateQueue",
        "runningJobsDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'stoppedByError'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'maxRatioChanged'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'seedingAutoStopped'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bt::AutoStopReason)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'aboutToBeStarted'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bool &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'missingFilesMarkedDND'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'corruptedDataFound'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'diskSpaceLow'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'torrentStopped'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'needDataCheck'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'chunkDownloaded'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *, bt::Uint32)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 22, 23 },
        }}),
        // Signal 'updateQueue'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runningJobsDone'
        QtMocHelpers::SignalData<void(bt::TorrentInterface *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TorrentInterface, qt_meta_tag_ZN2bt16TorrentInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject bt::TorrentInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16TorrentInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16TorrentInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2bt16TorrentInterfaceE_t>.metaTypes,
    nullptr
} };

void bt::TorrentInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TorrentInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 1: _t->stoppedByError((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->maxRatioChanged((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 3: _t->seedingAutoStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::AutoStopReason>>(_a[2]))); break;
        case 4: _t->aboutToBeStarted((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2]))); break;
        case 5: _t->missingFilesMarkedDND((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 6: _t->corruptedDataFound((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 7: _t->diskSpaceLow((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->torrentStopped((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 9: _t->needDataCheck((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 10: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        case 11: _t->chunkDownloaded((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::Uint32>>(_a[2]))); break;
        case 12: _t->updateQueue(); break;
        case 13: _t->runningJobsDone((*reinterpret_cast<std::add_pointer_t<bt::TorrentInterface*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * , QString )>(_a, &TorrentInterface::stoppedByError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::maxRatioChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * , bt::AutoStopReason )>(_a, &TorrentInterface::seedingAutoStopped, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * , bool & )>(_a, &TorrentInterface::aboutToBeStarted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::missingFilesMarkedDND, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::corruptedDataFound, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * , bool )>(_a, &TorrentInterface::diskSpaceLow, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::torrentStopped, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::needDataCheck, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::statusChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * , bt::Uint32 )>(_a, &TorrentInterface::chunkDownloaded, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)()>(_a, &TorrentInterface::updateQueue, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TorrentInterface::*)(bt::TorrentInterface * )>(_a, &TorrentInterface::runningJobsDone, 13))
            return;
    }
}

const QMetaObject *bt::TorrentInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::TorrentInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt16TorrentInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::TorrentInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void bt::TorrentInterface::finished(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void bt::TorrentInterface::stoppedByError(bt::TorrentInterface * _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void bt::TorrentInterface::maxRatioChanged(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void bt::TorrentInterface::seedingAutoStopped(bt::TorrentInterface * _t1, bt::AutoStopReason _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void bt::TorrentInterface::aboutToBeStarted(bt::TorrentInterface * _t1, bool & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void bt::TorrentInterface::missingFilesMarkedDND(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void bt::TorrentInterface::corruptedDataFound(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void bt::TorrentInterface::diskSpaceLow(bt::TorrentInterface * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void bt::TorrentInterface::torrentStopped(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void bt::TorrentInterface::needDataCheck(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void bt::TorrentInterface::statusChanged(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void bt::TorrentInterface::chunkDownloaded(bt::TorrentInterface * _t1, bt::Uint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void bt::TorrentInterface::updateQueue()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void bt::TorrentInterface::runningJobsDone(bt::TorrentInterface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
