/****************************************************************************
** Meta object code from reading C++ file 'downloader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libktorrent-26.07.80/src/download/downloader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'downloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2bt10DownloaderE_t {};
} // unnamed namespace

template <> constexpr inline auto bt::Downloader::qt_create_metaobjectdata<qt_meta_tag_ZN2bt10DownloaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "bt::Downloader",
        "ioError",
        "",
        "msg",
        "chunkDownloaded",
        "Uint32",
        "chunk",
        "update",
        "setMonitor",
        "bt::MonitorInterface*",
        "tmo",
        "dataChecked",
        "bt::BitSet",
        "ok_chunks",
        "bt::Uint32",
        "from",
        "to",
        "recalcDownloaded",
        "pieceReceived",
        "bt::Piece",
        "p",
        "finished",
        "bt::ChunkDownload*",
        "c"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ioError'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'chunkDownloaded'
        QtMocHelpers::SignalData<void(Uint32)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMonitor'
        QtMocHelpers::SlotData<void(bt::MonitorInterface *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'dataChecked'
        QtMocHelpers::SlotData<void(const bt::BitSet &, bt::Uint32, bt::Uint32)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 },
        }}),
        // Slot 'recalcDownloaded'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pieceReceived'
        QtMocHelpers::SlotData<void(const bt::Piece &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'finished'
        QtMocHelpers::SlotData<bool(bt::ChunkDownload *)>(21, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Downloader, qt_meta_tag_ZN2bt10DownloaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject bt::Downloader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt10DownloaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt10DownloaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2bt10DownloaderE_t>.metaTypes,
    nullptr
} };

void bt::Downloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Downloader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ioError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->chunkDownloaded((*reinterpret_cast<std::add_pointer_t<Uint32>>(_a[1]))); break;
        case 2: _t->update(); break;
        case 3: _t->setMonitor((*reinterpret_cast<std::add_pointer_t<bt::MonitorInterface*>>(_a[1]))); break;
        case 4: _t->dataChecked((*reinterpret_cast<std::add_pointer_t<bt::BitSet>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bt::Uint32>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bt::Uint32>>(_a[3]))); break;
        case 5: _t->recalcDownloaded(); break;
        case 6: _t->pieceReceived((*reinterpret_cast<std::add_pointer_t<bt::Piece>>(_a[1]))); break;
        case 7: { bool _r = _t->finished((*reinterpret_cast<std::add_pointer_t<bt::ChunkDownload*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Downloader::*)(const QString & )>(_a, &Downloader::ioError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Downloader::*)(Uint32 )>(_a, &Downloader::chunkDownloaded, 1))
            return;
    }
}

const QMetaObject *bt::Downloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::Downloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2bt10DownloaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PieceHandler"))
        return static_cast< PieceHandler*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::Downloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void bt::Downloader::ioError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void bt::Downloader::chunkDownloaded(Uint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
